"""API to EstradasPT."""
import logging
from collections import namedtuple
import aiohttp
import json

from .consts import API

_LOGGER = logging.getLogger(__name__)
_LOGGER.setLevel(logging.DEBUG)


class EstradasPT:
    """Interfaces to Estradas.pt"""

    def __init__(self, websession):
        self.websession = websession

    async def retrieve(self, url, **kwargs):
        """Issue API requests."""
        try:
            async with self.websession.request('GET', url, **kwargs) as res:
                if res.status != 200:
                    raise Exception("Could not retrieve information from API")
                if res.content_type == 'application/json':
                    return await res.json()
                return await res.text()
        except aiohttp.ClientError as err:
            logging.error(err)

    async def liveCameras(self):
        """Retrieve ongoing Cameras"""

        data = await self.retrieve(API)
        data = json.loads(data) # string to json      

        Cameras = namedtuple('Camera', ['id', 'name','url'])

        _cameras = []
        for camera in data['features']:

            _camera = Cameras(camera['attributes']['dbtrafego.telematicadata.EQUIPAMENTOS_DATEX.id'],
                                camera['attributes']['dbtrafego.telematicadata.cctv_url.descricao'],
                                camera['attributes']['dbtrafego.telematicadata.cctv_url.url']
            )
            _cameras.append(_camera)
       
        return _cameras



"""Representation of Cameras."""
import logging
from collections import namedtuple
import aiohttp

from .api import EstradasPT

logger = logging.getLogger(__name__)
logger.setLevel(logging.DEBUG)

class Cameras:
    """Represents cameras."""

    def __init__(self, websession):
        self.api = EstradasPT(websession)
     
    @classmethod
    async def get(cls, websession):

        self = Cameras(websession)
        self.cameras  = await self.api.liveCameras()
        
        return self

    async def liveCameras(self):
        """Retrieve Live cameras."""

        self.cameras = await self.api.liveCameras()

        return self.cameras
    
    async def UrlByCameraName(self, name):
        """function to return Video URL by camera name."""
        _url=''

        for c in self.cameras:
            if c.name == name:
                _url = c.url
        
        return _url

    async def UrlByCameraId(self, id):
        """function to return Video URL by camera id."""
        _url=''

        for c in self.cameras:
            if c.id == id:
                _url = c.url
        
        return _url


    async def full_list(self):
        """Retrieve ongoing cameras."""

        return self.cameras

    async def number_of_cameras(self):
           
        return len(self.cameras)



API = "http://www.estradas.pt/proxy.ashx?http://arcgis1.estradas.pt/arcgis/rest/services/Estradas/MapaEP/MapServer/1/query?f=json&where=dbtrafego.telematicadata.cctv_url.url%20is%20not%20null&returnGeometry=true&spatialRel=esriSpatialRelIntersects&outFields=dbtrafego.telematicadata.EQUIPAMENTOS_DATEX.id%2Cdbtrafego.telematicadata.EQUIPAMENTOS_DATEX.tipo%2Cdbtrafego.telematicadata.cctv_url.descricao%2Cdbtrafego.telematicadata.cctv_url.url"